@@ -1829,7 +1829,9 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
                          " all intervals set to 1.0")
                 intervals(temp) <- rep(1, ncol(temp)-1)
             }
-            sessions <- unique(primarysessions(intervals(temp))[occasions])
+            ## bug fixed 2021-04-22
+            # sessions <- unique(primarysessions(intervals(temp))[occasions])
+            sessions <- unique(primarysessions(interv)[occasions])
             sessionlabels(temp) <- slabels[sessions]
         }
         ################################################
@@ -2645,8 +2647,10 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
 
         if (byrow) {
             ## need delta-method variance of reals given object$beta.vcv & newdata
-            if (is.null(newdata))
-                newdata <- secr.make.newdata (object)
+            if (is.null(newdata)) {
+              # newdata <- secr.make.newdata (object)
+              newdata <- make.newdata (object)
+            }
             nreal <- length(realnames)
             nbeta <- length(object$fit$par)
 
