@@ -360,7 +360,7 @@ sim.popn <- function (D, core, buffer = 100, model2D = c("poisson",
                         covariates(recruits) <- data.frame(age = rep(0, nrow(recruits))) 
                     }
                     else {
-                        covariates(recruits)$age <- rep(0, nrow(nrecruits))
+                        covariates(recruits)$age <- rep(0, nrow(recruits))
                     }
                 }
                 lastnumber <<- lastnumber + nrecruit
