@@ -11,8 +11,9 @@
 ## 2020-01-26 selectCHsession
 ## 2020-02-21 secr 4.2.0
 ## 2020-05-15 stringsAsFactors function
-## 2020-07-14 secr 4.3.0distmat
+## 2020-07-14 secr 4.3.0 distmat
 ## 2020-09-05 getknownclass factor bug fixed
+## 2021-04-25 4.4.0
 #######################################################################################
 
 # Global variables in namespace
@@ -21,8 +22,8 @@
 ## e.g. Roger Peng https://stat.ethz.ch/pipermail/r-devel/2009-March/052883.html
 
 .localstuff <- new.env()
-.localstuff$packageType <- ' pre-release'
-# .localstuff$packageType <- ''
+#.localstuff$packageType <- ' pre-release'
+.localstuff$packageType <- ''
 .localstuff$validdetectors <- c('single','multi','proximity','count', 
     'polygonX', 'transectX', 'signal', 'polygon', 'transect', 
     'capped', 'null','null','null','null', 'telemetry', 'signalnoise')
@@ -34,7 +35,6 @@
     'signal', 'signalnoise', 'unmarked','presence','capped')
 .localstuff$polydetectors <- c('polygon','transect','polygonX','transectX')
 .localstuff$exclusivedetectors <- c('single','multi','polygonX','transectX')
-## 'signal' is not a count detector 2011-02-01
 .localstuff$countdetectors <- c('count','polygon','transect','unmarked','telemetry')
 .localstuff$iter <- 0   ## counter 1
 .localstuff$iter2 <- 0  ## counter 2
@@ -1640,18 +1640,6 @@ edist <- function (xy1, xy2) {
 
 ############################################################################################
 
-# maxdxy2 <- function (xy1, xy2) {
-#     nr <- nrow(xy1)
-#     nc <- nrow(xy2)
-#     x1 <- matrix(xy1[,1], nr, nc)
-#     x2 <- matrix(xy2[,1], nr, nc, byrow=T)
-#     y1 <- matrix(xy1[,2], nr, nc)
-#     y2 <- matrix(xy2[,2], nr, nc, byrow=T)
-#     pmax((x1-x2)^2, (y1-y2)^2)
-# }
-
-############################################################################################
-
 ## least cost paths from mask including barriers to movement
 ## use edist for equivalent Euclidean distances
 ## requires raster package
@@ -2006,11 +1994,16 @@ shareFactorLevels <- function (object, columns = NULL, stringsAsFactors = TRUE)
         }
     }
     else {
-        if (stringsAsFactors) {
-            if (is.null(columns)) {
-                columns <- 1:ncol(object)
+        # modified 2021-04-27 to apply to covariates, not object itself
+        if (!is.null(covariates(object))) {
+            if (stringsAsFactors) {
+                df <- covariates(object)
+                if (is.null(columns)) {
+                    columns <- 1:ncol(df)
+                }
+                df[,columns] <- stringsAsFactors(df[,columns, drop = FALSE])
+                covariates(object) <- df
             }
-            object[,columns] <- stringsAsFactors(object[,columns, drop = FALSE])
         }
     }
     object
