@@ -188,6 +188,13 @@ double zhvpr (const NumericVector param, const double r) {
 }
 //--------------------------------------------------------------------
 
+// hazard pixelar 
+double zhpxr (const NumericVector param, const double r) {
+    if (r<param[1]) return (1-exp(-param[0]));
+    else return (0);
+}
+//--------------------------------------------------------------------
+
 // hazard halfnormal 
 double zhhnrC (const std::vector<double> param, const double r) {
     return(param[0] * exp(- r * r / 2 / param[1] / param[1]));
@@ -411,6 +418,12 @@ double ghcgs (const std::vector<double> param, const double r) {
 double ghvps (const std::vector<double> param, const double r) {
     return(1 - exp( - param[0] * exp(- pow(r / param[1], param[2]))));
 }
+
+// hazard pixelar   
+double ghpxs (const std::vector<double> param, const double r) {
+    if (r<param[1]) return (1-exp(-param[0]));
+    else return (0);
+}
 //====================================================================
 //====================================================================
 
@@ -480,6 +493,8 @@ fnptrC getgfns (const int fn)
         return(ghcgs);
     else if (fn == 19)
         return(ghvps);
+    else if (fn == 20)
+        return(ghpxs);
     else // stop("unknown or invalid detection function");
         return(ghns);
 }
@@ -525,7 +540,9 @@ fnptr getzfnr (const int fn)
   else if (fn == 18)
     return(zhcgr);
   else if (fn == 19)
-    return(zhvpr);
+      return(zhvpr);
+  else if (fn == 20)
+      return(zhpxr);
   else (stop("unknown or invalid detection function"));
   return(zhnr);
 }
